# -*- coding: utf-8 -*-

from . import sequence_mixin
from . import partner
from . import res_partner_bank
from . import account_account_tag
from . import account_account
from . import account_journal
from . import account_tax
from . import account_reconcile_model
from . import account_payment_term
from . import account_move
from . import account_move_line
from . import account_move_line_tax_details
from . import account_partial_reconcile
from . import account_full_reconcile
from . import account_payment
from . import account_payment_method
from . import account_bank_statement
from . import account_bank_statement_line
from . import chart_template
from . import account_analytic_account
from . import account_analytic_distribution_model
from . import account_analytic_plan
from . import account_analytic_line
from . import account_journal_dashboard
from . import product
from . import company
from . import res_config_settings
from . import account_cash_rounding
from . import account_incoterms
from . import digest
from . import res_users
from . import ir_actions_report
from . import ir_attachment
from . import res_currency
from . import mail_thread
from . import account_report
